@@ -4,6 +4,7 @@ ZONE_FR_PAR_2 = Zone("fr-par-2")
 ZONE_FR_PAR_3 = Zone("fr-par-3")
 ZONE_NL_AMS_1 = Zone("nl-ams-1")
 ZONE_NL_AMS_2 = Zone("nl-ams-2")
+ZONE_NL_AMS_3 = Zone("nl-ams-3")
 ZONE_PL_WAW_1 = Zone("pl-waw-1")
 ZONE_PL_WAW_2 = Zone("pl-waw-2")
 
@@ -13,6 +14,7 @@ ALL_ZONES = [
     ZONE_FR_PAR_3,
     ZONE_NL_AMS_1,
     ZONE_NL_AMS_2,
+    ZONE_NL_AMS_3,
     ZONE_PL_WAW_1,
     ZONE_PL_WAW_2,
 ]
